django-hautomation
==================

REST API to control home automation deployments coded as Django apps


Django Home Automation is a set of Django apps which provides a REST API meant to
control home automation devices. It also provides a modular framework for
developing home automation drivers to enable more protocolos to be drived by this project.

The application by it self wont be enable to manage any home automation protocol
You need to install any protocol module to do this.

For example you can use https://github.com/jpardobl/hautomation_x10 to
manage X10 devices.


Further documentation found at http://jpardobl.com/home-automation-python-project/
